@@ -164,6 +164,12 @@ class MarkupField(models.TextField):
         else:
             return value
 
+    def get_searchable_content(self, value):
+        # Wagtail checks for existence of this method to determine what 
+        # value to index in its search backend. Incoming value comes from
+        # model_instance.field_name
+        return self.get_prep_value(value)
+
     def value_to_string(self, obj):
         if obj is not None:
             value = self.value_from_object(obj)
